//
//  ViewController.swift
//  PullDownCell
//
//  Created by Ali Raza on 11/02/2019.
//  Copyright © 2019 Ali Raza. All rights reserved.
//

import UIKit

class ViewController: UIViewController, IGGridViewDelegate, IGGridViewDataSource {

    @IBOutlet weak var gridView: IGGridView!
    
    override func viewDidLoad() {
        super.viewDidLoad()
        // Do any additional setup after loading the view, typically from a nib.
        // Hide the header
        self.gridView.headerHeight          = 44
        self.gridView.dataSource            = self
        self.gridView.delegate              = self
        self.gridView.rowSeparatorHeight    = 1.0
        self.gridView.rowSeparatorColor      = UIColor(red: 231/255, green: 231/255, blue: 231/255, alpha: 1.0)
        
        self.gridView.selectionType = .row
        
        self.gridView.clipsToBounds        = true
        self.gridView.layer.borderWidth     = 1.0
        self.gridView.layer.cornerRadius    = 6
        self.gridView.layer.borderColor     = UIColor.lightGray.cgColor
        
        
        perform(#selector(ViewController.updateData), with: nil, afterDelay: 1.0)
    }
    
    @objc private func updateData() {
        self.gridView.updateData()
    }

    //MARK: IGGridView Data Source and Delegate
    func gridView(_ gridView: IGGridView, numberOfRowsInSection section: Int) -> Int {
        
        return 0
    }
    
    func numberOfColumns(in gridView: IGGridView) -> Int {
        
        return 3
    }
    
    func gridView(_ gridView: IGGridView, heightForRowAt path: IGRowPath) -> CGFloat {
        
        return 50
    }
    
    
    
    func gridView(_ gridView: IGGridView, cellAt path: IGCellPath) -> IGGridViewCell{
        
        var cell = gridView.dequeueReusableCell(withIdentifier: "NameCell") as? ActivityGridCell
        
        if cell == nil {
            
            cell = ActivityGridCell(reuseIdentifier: "NameCell")
        }
        
        cell?.lblField.text = "Any text"
        
        return cell!
        
    }
    
    func gridView(_ gridView: IGGridView, titleForHeaderInColumn column: Int) -> String {
        
        switch column {

        case 0:
            return "  Name"
            
        case 1:
            return "  Contact/Product"
            
        case 2:
            return "  Description"
            
        default:
            return ""
            
        }
    }
    
    func numberOfFixedRows(in gridView: IGGridView) -> Int {
        
        return 0
    }
    
    //MARK: Delgate
    func gridView(_ gridView: IGGridView, widthForColumnAt column: Int) -> IGColumnWidth {
        
        let width = (gridView.frame.size.width) / 3
        
        return IGColumnWidth (width: width)
        
    }
    
    func gridView(_ gridView: IGGridView, headerCellAt column: Int) -> IGGridViewHeaderCell {
        
        
        var cell : IGGridViewHeaderCell? = nil
        cell = gridView.dequeueReusableCell(withIdentifier: "headerCell") as? IGGridViewHeaderCell
        
        if cell == nil {
            
            cell = IGGridViewHeaderCell(reuseIdentifier: "headerCell")
        }
        
        cell?.backgroundColor = UIColor(red: 248/255, green: 248/255, blue: 248/255, alpha: 1.0)
        
        cell?.textLabel.textColor = UIColor.black
        cell?.textLabel.font = UIFont.boldSystemFont(ofSize: 17)
        
        
        switch column {
       
        case 0:
            cell?.textLabel.text = "  Prospect Name"
            
        case 1:
            cell?.textLabel.text = "  Contact/Product"
            
        case 2:
            cell?.textLabel.text = "  Description"
        
        default :
            cell?.textLabel.text = ""
            
        }
        
        cell?.layer.borderWidth = 1.0
        cell?.layer.borderColor = UIColor(red: 231/255, green: 231/255, blue: 231/255, alpha: 1.0).cgColor
        
        return cell!
    }
    
    func pullDownCell(for gridView: IGGridView) -> IGGridViewPullDownCell {
        
        var cell = gridView.dequeueReusableCell(withIdentifier: "pullDownCell") as? PullDownCell
        
        if cell == nil {
            cell = PullDownCell(reuseIdentifier: "pullDownCell")
            cell!.pullDownIndicator.startAnimating()
            cell!.backgroundColor = UIColor.white
        }
        
        return cell!
    }
    
    //MARK: Delgate
    func updateRequested(in gridView: IGGridView) {
        
        print("updateRequested")
        gridView.finishedUpdating()
    }
    
}

class PullDownCell: IGGridViewPullDownCell {
    
    let pullDownIndicator   = UIActivityIndicatorView(style: .gray)
    let lblPullText   = UILabel()
    
    override init(reuseIdentifier identifier: String) {
        super.init(reuseIdentifier: identifier)
        setup()
    }
    
    required init?(coder aDecoder: NSCoder) {
        
        super.init(coder: aDecoder)
        setup()
    }
    
    override init(frame: CGRect) {
        super.init(frame: frame)
        setup()
    }
    private func setup() {
        
        lblPullText.textColor         = UIColor.black
        lblPullText.isHidden            = true
        lblPullText.text              = ""
        lblPullText.backgroundColor   = UIColor.clear
        lblPullText.font              = UIFont(name: "Helvetica", size: 15)
        lblPullText.textColor         = UIColor.black
        lblPullText.textAlignment     = .center
        self.addSubview(lblPullText)
        
        pullDownIndicator.startAnimating()
        
        self.addSubview(pullDownIndicator)
    }
    
    
    override func cellAttached() {
        super.cellAttached()
        pullDownIndicator.isHidden  = false
        lblPullText.isHidden    = false
    }
    
    override func setupSize(_ size: CGSize) {
        super.setupSize(size)
        pullDownIndicator.frame   = CGRect(x: size.width/2 - 15, y: 0, width: 30, height: 30)
        lblPullText.frame     = CGRect(x: 0, y: 30, width: size.width, height: 20)
        
    }
    
    override func changeStateToPullDownMode() {
        
        lblPullText.text    = "Pull down to refresh..."
    }
    
    override func changeStateToReleaseMode() {
        
        lblPullText.text    = "Release to refresh..."
    }
    
    override func changeStateToUpdatingMode() {
        
        lblPullText.text    = "Refreshing..."
    }
}
